import json
from ruamel.yaml.representer import SafeRepresenter as RuamelSafeRepresenter
from typing import Any, IO

def format_output_data(obj: Any) -> Any: ...
def is_invalid(value: Any) -> bool: ...
def filter_data(data: Any) -> Any: ...

class ValidRepresenter(RuamelSafeRepresenter):
    def represent(self, data: Any) -> None: ...
    def represent_data(self, data: Any) -> Any: ...

def valid_dump_yaml(data: Any, stream: IO[str], **kwds: Any) -> None: ...
def valid_dumps_yaml(data: Any, **kwds: Any) -> str | None: ...
def safe_loads_yaml(content: str) -> Any: ...

class TaranJSONEncoder(json.JSONEncoder):
    def default(self, obj: Any) -> Any: ...

def safe_dumps_json(obj: Any, **kwargs: Any) -> str: ...
